@@ -20,11 +20,12 @@ Geocoder is an Apache2 Licensed Geocoding library, written in Python.
 """
 
 __title__ = 'geocoder'
-__version__ = '0.6.1'
+__version__ = '0.6.2'
 __author__ = 'Denis Carriere'
 __license__ = 'Apache 2.0'
 __copyright__ = 'Copyright 2014 Denis Carriere'
 
 
 from api import arcgis, bing, geonames, google, mapquest, nokia, osm, tomtom
-from api import get, population, reverse, ip, elevation, canadapost
+from api import get, population, reverse, ip, canadapost, geolytica
+from api import timezone, elevation
