@@ -1,3 +1,6 @@
+#!/usr/bin/python
+# coding: utf8
+
 from base import Base
 
 
@@ -16,27 +19,43 @@ class Tomtom(Base):
         if not key:
             self.help_key()
 
+    @property
     def lat(self):
         return self.safe_coord('geoResult-latitude')
 
+    @property
     def lng(self):
         return self.safe_coord('geoResult-longitude')
 
+    @property
+    def street_number(self):
+        return self.safe_format('geoResult-houseNumber')
+
+    @property
+    def route(self):
+        return self.safe_format('geoResult-street')
+
+    @property
     def address(self):
         return self.safe_format('geoResult-formattedAddress')
 
+    @property
     def quality(self):
         return self.safe_format('geoResult-type')
 
+    @property
     def postal(self):
         return self.safe_format('geoResult-postcode')
 
+    @property
     def locality(self):
         return self.safe_format('geoResult-city')
 
+    @property
     def state(self):
         return self.safe_format('geoResult-state')
 
+    @property
     def country(self):
         return self.safe_format('geoResult-country')
 
@@ -48,4 +67,4 @@ class Tomtom(Base):
         print ''
         print 'How to get a Key?'
         print '-----------------'
-        print 'http://developer.tomtom.com/products/geocoding_api'
\ No newline at end of file
+        print 'http://developer.tomtom.com/products/geocoding_api'
